==========
Jet Bridge
==========

**Universal admin panel for Django**

.. image:: https://raw.githubusercontent.com/jet-admin/jet-bridge/master/static/overview.gif
    :alt: Preview
    :align: center
    :target: https://raw.githubusercontent.com/jet-admin/jet-bridge/master/static/overview.gif

Description
===========

* Jet Admin: https://jetadmin.io
* **Live Demo**: https://app.jetadmin.io/demo
* Support: support@jetadmin.io

**Jet** is a SaaS service that automatically generates back office for your Django Application through REST API of **Jet Bridge** package installed to your project.

– **Visual**. Admin interface can be easily changed without need of development with the help of Visual Editor. 

– **Secure**. Jet does not access your data: its transferred directly from browser to your application.

– **Customizable**. Flex functions allow you to solve your specific business tasks when standard functionality is not enough.

This is a complete remake of popular `Django Jet <https://github.com/geex-arts/django-jet>`_ admin interface.

Features
========

- **CRUD (create, read, update, delete):**
  
  Create, view, update and delete data. Display it in an easy format, and then search and filter your data.

- **Dashboard:** 

  Create reports and visualize KPIs. Monitor new data like new orders, comments, etc.
  
- **Works with any technology:** 

  The interface is generated automatically based on an analysis of the data and data structure of your applications.

- **Visual editor:** 
  
  Customize the admin area to make it easy for any manager to use. Allow managers to modify the interface, configure features, and set up analytics widgets without using any developers — just like WIX, Squarespace….

- **Secure:** 

  Your data is safe. We do not have access to your information. We simply plug your information in to an easy-to-use interface for you to interact with it better.

- **Works on any device:** 

  The interface is optimized for any device from phones to tablets to desktops.

- **Quick installation:** 

  It takes only a few hours to integrate with your project.

- **Available 24/7:**

  Use it around the clock and don’t worry about updates — we take care of that.

- **Manage users:**

  Assign access rights to any data from within the panel.

- **Activity log:**

  Track the history of all changes and know who made them.

Requirements
============

WIP

Installation
============

WIP

Support
=======

Feel free to Email us – support@jetadmin.io

License
=======

This project is **MIT** licensed - see the LICENCE file for details.
